
# DO NOT EDIT THIS FILE -- AUTOGENERATED BY PANTS
# Target: src/underpants:dist

from setuptools import setup

setup(**{
    'classifiers': [
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Software Development :: Libraries',
    ],
    'description': 'Leverage the Rules Engine from the Pants Build System as a library.',
    'install_requires': (
    ),
    'license': 'MIT',
    'name': 'underpants',
    'namespace_packages': (
    ),
    'package_data': {
    },
    'packages': (
    ),
    'project_urls': {
        'Documentation': 'https://github.com/kaos/underpants/wiki',
        'Source': 'https://github.com/kaos/underpants',
        'Tracker': 'https://github.com/kaos/underpants/issues',
    },
    'version': '0.1.0',
})
